@@ -60,6 +60,9 @@
     }
   }
   defineEventHandler(AbortSignal.prototype, "abort");
+
+  webidl.configurePrototype(AbortSignal);
+
   class AbortController {
     #signal = new AbortSignal(illegalConstructorKey);
 
@@ -76,6 +79,8 @@
     }
   }
 
+  webidl.configurePrototype(AbortController);
+
   const handlerSymbol = Symbol("eventHandlers");
 
   function makeWrappedHandler(handler) {
@@ -118,11 +123,25 @@
     AbortSignal,
   );
 
+  function newSignal() {
+    return new AbortSignal(illegalConstructorKey);
+  }
+
+  function follow(followingSignal, parentSignal) {
+    if (parentSignal.aborted) {
+      followingSignal[signalAbort]();
+    } else {
+      parentSignal[add](() => followingSignal[signalAbort]());
+    }
+  }
+
   window.AbortSignal = AbortSignal;
   window.AbortController = AbortController;
   window.__bootstrap.abortSignal = {
     add,
     signalAbort,
     remove,
+    follow,
+    newSignal,
   };
 })(this);
